@@ -842,7 +842,7 @@ with a prefix, caching will be temporarily disabled.
 Examples:
 a-f     auto-fill-mode
 r-e     rmail-expunge
-b--d    *begining-of-defun or byte-recompile-directory
+b--d    *beginning-of-defun or byte-recompile-directory
 by  d   *byte-recompile-directory if completer-any-delimiter is \" \"
 ~/i.e   *~/ilisp.el or ~/il-el.el or ~/ilisp.elc
 /u/mi/  /usr/misc/"
